package com.leromro.core.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.leromro.common.exception.ServiceException;
import com.leromro.core.domain.BusinessManagement;
import com.leromro.core.domain.BusinessPrice;
import com.leromro.core.domain.VolunteerInfo;
import com.leromro.core.domain.dto.VolunteerInfoDTO;
import com.leromro.core.domain.vo.VolunteerInfoDetailVO;
import com.leromro.core.mapper.VolunteerInfoMapper;
import com.leromro.core.service.IBusinessManagementService;
import com.leromro.core.service.IBusinessPriceService;
import com.leromro.core.service.IVolunteerInfoService;
import com.leromro.core.utils.DateTimeUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 志愿者信息表 服务实现类
 * </p>
 *
 * @author lr
 * @since 2025-04-07
 */
@Service
public class VolunteerInfoServiceImpl extends ServiceImpl<VolunteerInfoMapper, VolunteerInfo> implements IVolunteerInfoService {

    @Autowired
    private VolunteerInfoMapper volunteerInfoMapper;

    @Autowired
    private IBusinessManagementService businessManagementService;

    @Autowired
    private IBusinessPriceService businessPriceService;

    /**
     * 新增志愿者信息
     * @param volunteerInfo
     * @param userId
     * @param serviceCategory
     */
    @Override
    public void newVolunteerInfoByuserId(VolunteerInfo volunteerInfo, Long userId, Long serviceCategory) {
        //查询业务管理信息
        BusinessManagement businessManagement = businessManagementService.getOne(new LambdaQueryWrapper<BusinessManagement>()
                .eq(BusinessManagement::getBusinessManagementId, volunteerInfo.getBusinessManagementId()));
        if (StrUtil.isBlank(businessManagement.getBusinessTierName()) || businessManagement.getBusinessTierName().length() < 2){
            throw new RuntimeException("当前服务项目层级名称错误");
        }
        //把BusinessTierName按照-分割
        String[] businessTierName = businessManagement.getBusinessTierName().split("-");
        volunteerInfo.setProjectName(businessTierName[0]);
        volunteerInfo.setProjectTypeName(businessTierName[1]);

        volunteerInfo.setVolunteerId(userId);
        volunteerInfo.setServiceCategory(serviceCategory);
        volunteerInfo.setCreateTime(DateTimeUtil.getNowTime());
        QueryWrapper<VolunteerInfo> wrapper = new QueryWrapper<>();
        wrapper.eq("volunteer_id",userId).eq("service_category",serviceCategory);

        Integer i = volunteerInfoMapper.selectCount(wrapper);
        if(i>0){
            throw new RuntimeException("此用户已有志愿者信息，不可重复创建，请前往修改");
        }
        if (ObjectUtil.isNull(volunteerInfo.getVolunteerInfoId())) {
            this.save(volunteerInfo);
        }else {
            volunteerInfo.setAppStatus("1");
            volunteerInfoMapper.updateById(volunteerInfo);
        }

    }

    /**
     * 志愿者注册信息回显
     * @param serviceCategory
     * @param userId
     * @return
     */
    @Override
    public VolunteerInfo selectByUserID(Long serviceCategory, Long userId) {
        QueryWrapper<VolunteerInfo> wrapper = new QueryWrapper<>();
        wrapper.eq("volunteer_id",userId).eq("service_category",serviceCategory);
        VolunteerInfo infos = volunteerInfoMapper.selectOne(wrapper);
        return infos;
    }

    /**
     * @param dto
     * @return
     */
    @Override
    public List<VolunteerInfo> selectVolunteerInfoList(VolunteerInfoDTO dto) {

        List<VolunteerInfo> infos = volunteerInfoMapper.selectVolunteerInfoSimple(dto);
        return infos;
    }
    /**
     * @param volunteerInfo
     * @return
     */
    @Override
    public List<VolunteerInfo> selectVolunteerInfoList1(VolunteerInfo volunteerInfo) {

        List<VolunteerInfo> infos = volunteerInfoMapper.selectVolunteerInfoSimple1(volunteerInfo);
        return infos;
    }

    /**
     * @param
     * @return
     */
    @Override
    public VolunteerInfoDetailVO selectLVolunteerInfoByVolunteerId(VolunteerInfo volunteerInfo) {
        VolunteerInfo info = this.getOne(new LambdaQueryWrapper<VolunteerInfo>()
                .eq(VolunteerInfo::getVolunteerId, volunteerInfo.getVolunteerId())
                .eq(VolunteerInfo::getBusinessManagementId, volunteerInfo.getBusinessManagementId()));
        if (ObjectUtil.isNull(info)){
            throw new ServiceException("获取志愿者信息异常，请稍后再试");
        }
        VolunteerInfoDetailVO vo = BeanUtil.copyProperties(info, VolunteerInfoDetailVO.class);
        //实时查询当前业务的服务费和服务时长
        BusinessPrice price = businessPriceService.getOne(new LambdaQueryWrapper<BusinessPrice>()
                .eq(BusinessPrice::getBusinessManagementId, info.getBusinessManagementId()));
        if (ObjectUtil.isNull(price) || ObjectUtil.isNull(price.getBusinessPrice())){
            throw new ServiceException("服务价格获取异常，请稍后再试");
        }

        vo.setBusinessPrice(price.getBusinessPrice());
        vo.setBusinessDuration(price.getBusinessDuration());
        return vo;
    }
}
